webbpsf\_ext.bandpasses
=======================

.. automodule:: webbpsf_ext.bandpasses

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      bp_2mass
      bp_gaia
      bp_igood
      bp_wise
      miri_filter
      nircam_com_nd
      nircam_com_th
      nircam_filter
      nircam_grism_res
      nircam_grism_wref
      niriss_grism_res
      niriss_grism_wref
      read_filter
   
   

   
   
   

   
   
   



